
***********************************************************************************
* Environment set up
***********************************************************************************
clear
set more off
cap log close

* Set working directory (depending on where you want to work with the downloaded data)
global dir_main "C:\YOUR_DATA_FOLDER"

* Specify subfolders
	*Input files
	global dir_encrypt "MICRODATA" // please put your downloaded data here

	*Output files	
	global dir_graphs "GRAPHS"
	
	*Temporary files
	global dir_temp "TEMP"
	
	*Scale
	global scale 1

* Make directories
cap mkdir ${dir_main}
cap mkdir ${dir_main}\\${dir_encrypt}
cap mkdir ${dir_main}\\${dir_graphs}
cap mkdir ${dir_main}\\${dir_temp}

*Install user-written commands
cap noisily ssc install egenmore

*Go to the working directory
cd "${dir_main}"


***********************************************************************************
* Make price indices for different good (Chinese and Non_Chinese goods) and retail (All Retails, Retail 1 and Retail 2) groups.
* 
* Monthly version
***********************************************************************************

**Retailer codes
*ALL is the combined dataset with both retailers. 
*R1 is "Retailer 1"
*R2 is "Retailer 2"

**Goods codes
*china = 1 is Chinese goods
*china = 0 is Non_Chinese goods
*impacted = 9 is all categories (with no distinction between affected and not affected categories)

**Input files (obstained from \REPLICATION\RETAIL\MICRODATA and saved in MICRODATA folder)
*ALL_alldata_monthly.dta
*R1_alldata_monthly.dta
*R2_alldata_monthly.dta

***Output files
**Data files （saved in TEMP folder）
*ALL_index_m_c0_i9.dta
*ALL_index_m_c1_i9.dta
*R1_index_m_c0_i9.dta
*R1_index_m_c1_i9.dta
*R2_index_m_c0_i9.dta
*R2_index_m_c1_i9.dta

**Graph files (saved in GRAPHS folder)
*Figure_A_ALL.pdf
*Figure_A_R1.pdf
*Figure_A_R2.pdf


global listretailer "ALL R1 R2" 

foreach retailer in $listretailer {
global retailer `retailer'

foreach china in 1 0 { 
	foreach impacted in 9{
		use "${dir_encrypt}\\${retailer}_alldata_monthly.dta" , clear
		keep if china==`china'

		* Make monthly
		capture drop date
		gen date=ym
		tsset id date

		* AGGREGATE INDEX
		* Get individual product price relative
		gen relative=price/l.price

		* Remove outliers --following ILO CPI Manual 2004
		replace relative=1 if relative>10 & relative!=.
		replace relative=1 if relative<0.1 & relative!=.

		* Get geometric mean by date
		bysort date: egen mean_all=gmean(relative)
		keep date mean_all

		* First collapse to each date. Note missing dates will not be in data, so use [_n-1] below, not tsset
		egen tag = tag(date)
		keep if tag==1

		* Create index
		egen daymin=min(date)
		format daymin %td
		gen index=1 if date==daymin

		replace mean_all=1 if mean_all==.
		replace index=mean_all*index[_n-1] if index==.
		label var index "Index"
		keep date index
		tsset date

		save ${dir_temp}\\${retailer}_index_m_c`china'_i`impacted'.dta, replace
	}
}




clear
* All chinese goods
use ${dir_temp}\\${retailer}_index_m_c1_i9.dta, clear
ren (index) (index_c9)
* All non-chinese goods
merge 1:1 date using ${dir_temp}\\${retailer}_index_m_c0_i9.dta, nogen
ren (index) (index_n9)

*Normalize indices: this version normalizes to the annual inflation on June 2018 (1 month before the first round of tariffs)
foreach var in c9 n9 {
	gen index_`var'_base0=index_`var' if date==701
	egen index_`var'_base=max(index_`var'_base0)
	gen norm_index_`var'=index_`var'/index_`var'_base
	drop index_`var'_base index_`var'_base0
}

foreach var in norm_index {
	label var `var'_c9 "Chinese Goods"
	label var `var'_n9 "Non-Chinese Goods"
}

format date %tm

* Important dates:
	* January 2018: US imposes tariffs on washing machines, solar cells , all countries
	display ym(2018,1)

	* March 2018: Trump signs tariffs on steel and alumimiun, all countries
	* US proposes tariffs in response to China's "unfair trade practices"
	* USTR releases proposed product tariff on $50B of chinese goods
	display ym(2018,3)

	* April 2018: USTR confirms tariffs on $34B, proposes tariffs on another $16B
	display ym(2018,4)

	* July 2018: 25% tariff becomes effective on $ 34 Billion China imports
	* USTR proposes 10% on $200B, to be increased to 25% at end of year
	display ym(2018,7)

	* August 2018: 25% tariff becomes effective on $ 16 Billion China imports began
	display ym(2018,8)

	* September 2018: 10% tariff becomes effective on $ 200 Billion Chinese products
	display ym(2018,9)

	* May 2019: 10% tariff braised to 25% on $ 200 Billion Chinese products
	display ym(2019,5)

local jan 
local jul 
forvalues y = 2017/2020 {
	local jan `jan' `=ym(`y',1)'
	local jul `jul' `=ym(`y',7)'
}

* FIGURE - CHINA VS NOT CHINA
line norm_index_c9 norm_index_n9 date , ///
xline(702 703 704 712 716, lcolor(black) lwidth(thin)) lcolor(red red navy navy)  ///
ytitle("Price Index" " ") xtitle("") xlabel(`jan', format(%tmCY) noticks) xtick(`jan') ///
lpattern(dash solid dash solid) legend(order ( 4 2 3 1) region(lwidth(none)) symxsize(5) ) ///
scale(${scale}) ///
graphregion(fcolor(white))  
graph export ${dir_graphs}\\Figure_A_${retailer}.pdf , replace
}



